@@ -44,13 +44,6 @@ static gboolean cheese_camera_device_initable_init (GInitable    *initable,
                                                     GCancellable *cancellable,
                                                     GError      **error);
 
-G_DEFINE_TYPE_WITH_CODE (CheeseCameraDevice, cheese_camera_device, G_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
-                                                cheese_camera_device_initable_iface_init))
-
-#define CHEESE_CAMERA_DEVICE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CHEESE_TYPE_CAMERA_DEVICE, \
-                                                                          CheeseCameraDevicePrivate))
-
 #define CHEESE_CAMERA_DEVICE_ERROR cheese_camera_device_error_quark ()
 
 /*
@@ -114,6 +107,12 @@ struct _CheeseCameraDevicePrivate
   GError *construct_error;
 };
 
+G_DEFINE_TYPE_WITH_CODE (CheeseCameraDevice, cheese_camera_device,
+                         G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (CheeseCameraDevice)
+                         G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
+                                                cheese_camera_device_initable_iface_init))
+
 /*
  * This is our private version of CheeseVideoFormat, with extra fields added
  * at the end. IMPORTANT the first fields *must* be kept in sync with the
@@ -330,18 +329,21 @@ static CheeseVideoFormatFull *
 cheese_camera_device_find_full_format (CheeseCameraDevice *device,
                                        CheeseVideoFormat* format)
 {
+    CheeseCameraDevicePrivate *priv;
   GList *l;
 
-  for (l = device->priv->formats; l != NULL; l = g_list_next (l))
-  {
-    CheeseVideoFormatFull *item = l->data;
+    priv = cheese_camera_device_get_instance_private (device);
 
-    if ((item != NULL) &&
-        (item->width == format->width) && (item->height == format->height))
+    for (l = priv->formats; l != NULL; l = g_list_next (l))
     {
-      return item;
+        CheeseVideoFormatFull *item = l->data;
+
+        if ((item != NULL) &&
+            (item->width == format->width) && (item->height == format->height))
+        {
+            return item;
+        }
     }
-  }
 
   return NULL;
 }
@@ -358,9 +360,10 @@ cheese_camera_device_add_format (CheeseCameraDevice *device,
                                  CheeseVideoFormatFull *format,
                                  const GValue *framerate)
 {
-  CheeseCameraDevicePrivate *priv = device->priv;
+    CheeseCameraDevicePrivate *priv;
   CheeseVideoFormatFull *existing;
 
+    priv = cheese_camera_device_get_instance_private (device);
   existing = cheese_camera_device_find_full_format (device,
                                                     (CheeseVideoFormat *)format);
 
@@ -376,8 +379,8 @@ cheese_camera_device_add_format (CheeseCameraDevice *device,
   GST_INFO ("%dx%d framerate %d/%d", format->width, format->height,
             format->fr_numerator, format->fr_denominator);
 
-  priv->formats = g_list_insert_sorted (priv->formats, format,
-                                        compare_formats);
+    priv->formats = g_list_insert_sorted (priv->formats, format,
+                                          compare_formats);
 }
 
 /*
@@ -401,7 +404,9 @@ free_format_list_foreach (gpointer data)
 static void
 free_format_list (CheeseCameraDevice *device)
 {
-  CheeseCameraDevicePrivate *priv = device->priv;
+    CheeseCameraDevicePrivate *priv;
+
+    priv = cheese_camera_device_get_instance_private (device);
 
   g_list_free_full (priv->formats, free_format_list_foreach);
   priv->formats = NULL;
@@ -417,13 +422,14 @@ free_format_list (CheeseCameraDevice *device)
 static void
 cheese_camera_device_update_format_table (CheeseCameraDevice *device)
 {
-  CheeseCameraDevicePrivate *priv = device->priv;
+    CheeseCameraDevicePrivate *priv;
 
   guint i;
   guint num_structures;
 
   free_format_list (device);
 
+    priv = cheese_camera_device_get_instance_private (device);
   num_structures = gst_caps_get_size (priv->caps);
   for (i = 0; i < num_structures; i++)
   {
@@ -514,8 +520,7 @@ cheese_camera_device_update_format_table (CheeseCameraDevice *device)
 static void
 cheese_camera_device_get_caps (CheeseCameraDevice *device)
 {
-  CheeseCameraDevicePrivate *priv = device->priv;
-
+    CheeseCameraDevicePrivate *priv;
   gchar               *pipeline_desc;
   GstElement          *pipeline;
   GstStateChangeReturn ret;
@@ -523,6 +528,7 @@ cheese_camera_device_get_caps (CheeseCameraDevice *device)
   GstBus              *bus;
   GError              *err = NULL;
 
+    priv = cheese_camera_device_get_instance_private (device);
   pipeline_desc = g_strdup_printf ("%s name=source device=%s ! fakesink",
                                    priv->src, priv->device_node);
   pipeline = gst_parse_launch (pipeline_desc, &err);
@@ -606,7 +612,7 @@ static void
 cheese_camera_device_constructed (GObject *object)
 {
   CheeseCameraDevice        *device = CHEESE_CAMERA_DEVICE (object);
-  CheeseCameraDevicePrivate *priv   = device->priv;
+    CheeseCameraDevicePrivate *priv = cheese_camera_device_get_instance_private (device);
 
   priv->src = (priv->v4lapi_version == 2) ? "v4l2src" : "v4lsrc";
 
@@ -620,7 +626,7 @@ static void
 cheese_camera_device_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
   CheeseCameraDevice        *device = CHEESE_CAMERA_DEVICE (object);
-  CheeseCameraDevicePrivate *priv   = device->priv;
+    CheeseCameraDevicePrivate *priv = cheese_camera_device_get_instance_private (device);
 
   switch (prop_id)
   {
@@ -646,7 +652,7 @@ static void
 cheese_camera_device_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
   CheeseCameraDevice        *device = CHEESE_CAMERA_DEVICE (object);
-  CheeseCameraDevicePrivate *priv   = device->priv;
+  CheeseCameraDevicePrivate *priv = cheese_camera_device_get_instance_private (device);
 
   switch (prop_id)
   {
@@ -678,7 +684,7 @@ static void
 cheese_camera_device_finalize (GObject *object)
 {
   CheeseCameraDevice        *device = CHEESE_CAMERA_DEVICE (object);
-  CheeseCameraDevicePrivate *priv   = device->priv;
+    CheeseCameraDevicePrivate *priv = cheese_camera_device_get_instance_private (device);
 
   g_free (priv->device_node);
   g_free (priv->uuid);
@@ -759,8 +765,6 @@ cheese_camera_device_class_init (CheeseCameraDeviceClass *klass)
                                                        G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, PROP_LAST, properties);
-
-  g_type_class_add_private (klass, sizeof (CheeseCameraDevicePrivate));
 }
 
 static void
@@ -772,17 +776,10 @@ cheese_camera_device_initable_iface_init (GInitableIface *iface)
 static void
 cheese_camera_device_init (CheeseCameraDevice *device)
 {
-  CheeseCameraDevicePrivate *priv = device->priv = CHEESE_CAMERA_DEVICE_GET_PRIVATE (device);
+    CheeseCameraDevicePrivate *priv = cheese_camera_device_get_instance_private (device);
 
-  priv->device_node = NULL;
-  priv->uuid = NULL;
-  priv->src = NULL;
   priv->name = g_strdup (_("Unknown device"));
   priv->caps = gst_caps_new_empty ();
-
-  priv->formats = NULL;
-
-  priv->construct_error = NULL;
 }
 
 static gboolean
@@ -791,7 +788,7 @@ cheese_camera_device_initable_init (GInitable    *initable,
                                     GError      **error)
 {
   CheeseCameraDevice        *device = CHEESE_CAMERA_DEVICE (initable);
-  CheeseCameraDevicePrivate *priv   = device->priv;
+    CheeseCameraDevicePrivate *priv = cheese_camera_device_get_instance_private (device);
 
   g_return_val_if_fail (CHEESE_IS_CAMERA_DEVICE (initable), FALSE);
 
@@ -859,9 +856,13 @@ cheese_camera_device_new (const gchar *uuid,
 GList *
 cheese_camera_device_get_format_list (CheeseCameraDevice *device)
 {
+    CheeseCameraDevicePrivate *priv;
+
   g_return_val_if_fail (CHEESE_IS_CAMERA_DEVICE (device), NULL);
 
-  return g_list_copy (device->priv->formats);
+    priv = cheese_camera_device_get_instance_private (device);
+
+    return g_list_copy (priv->formats);
 }
 
 /**
@@ -876,9 +877,13 @@ cheese_camera_device_get_format_list (CheeseCameraDevice *device)
 const gchar *
 cheese_camera_device_get_name (CheeseCameraDevice *device)
 {
+    CheeseCameraDevicePrivate *priv;
+
   g_return_val_if_fail (CHEESE_IS_CAMERA_DEVICE (device), NULL);
 
-  return device->priv->name;
+    priv = cheese_camera_device_get_instance_private (device);
+
+    return priv->name;
 }
 
 /**
@@ -892,9 +897,13 @@ cheese_camera_device_get_name (CheeseCameraDevice *device)
 const gchar *
 cheese_camera_device_get_uuid (CheeseCameraDevice *device)
 {
+    CheeseCameraDevicePrivate *priv;
+
   g_return_val_if_fail (CHEESE_IS_CAMERA_DEVICE (device), NULL);
 
-  return device->priv->uuid;
+    priv = cheese_camera_device_get_instance_private (device);
+
+    return priv->uuid;
 }
 
 /**
@@ -910,9 +919,13 @@ cheese_camera_device_get_uuid (CheeseCameraDevice *device)
 const gchar *
 cheese_camera_device_get_src (CheeseCameraDevice *device)
 {
+    CheeseCameraDevicePrivate *priv;
+
   g_return_val_if_fail (CHEESE_IS_CAMERA_DEVICE (device), NULL);
 
-  return device->priv->src;
+    priv = cheese_camera_device_get_instance_private (device);
+
+    return priv->src;
 }
 
 /**
@@ -927,9 +940,13 @@ cheese_camera_device_get_src (CheeseCameraDevice *device)
 const gchar *
 cheese_camera_device_get_device_node (CheeseCameraDevice *device)
 {
+    CheeseCameraDevicePrivate *priv;
+
   g_return_val_if_fail (CHEESE_IS_CAMERA_DEVICE (device), NULL);
 
-  return device->priv->device_node;
+    priv = cheese_camera_device_get_instance_private (device);
+
+    return priv->device_node;
 }
 
 /**
@@ -946,29 +963,33 @@ cheese_camera_device_get_device_node (CheeseCameraDevice *device)
 CheeseVideoFormat *
 cheese_camera_device_get_best_format (CheeseCameraDevice *device)
 {
+    CheeseCameraDevicePrivate *priv;
   CheeseVideoFormatFull *format = NULL;
   GList *l;
 
   g_return_val_if_fail (CHEESE_IS_CAMERA_DEVICE (device), NULL);
 
-  /* Check for the highest resolution with width >= 640 and FPS >= 15. */
-  for (l = device->priv->formats; l != NULL; l = g_list_next (l))
-  {
-    CheeseVideoFormatFull *item = l->data;
-    float frame_rate = (float)item->fr_numerator / (float)item->fr_denominator;
+    priv = cheese_camera_device_get_instance_private (device);
 
-    if (item->width >= 640 && frame_rate >= 15)
+    /* Check for the highest resolution with width >= 640 and FPS >= 15. */
+    for (l = priv->formats; l != NULL; l = g_list_next (l))
     {
-      format = item;
-      break;
-    }
-  }
+        CheeseVideoFormatFull *item = l->data;
+        float frame_rate = (float)item->fr_numerator
+                           / (float)item->fr_denominator;
 
-  /* Else simply return the highest resolution. */
-  if (!format)
-  {
-    format = device->priv->formats->data;
-  }
+        if (item->width >= 640 && frame_rate >= 15)
+        {
+            format = item;
+            break;
+        }
+    }
+
+    /* Else simply return the highest resolution. */
+    if (!format)
+    {
+        format = priv->formats->data;
+    }
 
   GST_INFO ("%dx%d@%d/%d", format->width, format->height,
             format->fr_numerator, format->fr_denominator);
@@ -1009,6 +1030,7 @@ GstCaps *
 cheese_camera_device_get_caps_for_format (CheeseCameraDevice *device,
                                           CheeseVideoFormat  *format)
 {
+    CheeseCameraDevicePrivate *priv;
   CheeseVideoFormatFull *full_format;
   GstCaps *desired_caps;
   GstCaps *subset_caps;
@@ -1038,7 +1060,8 @@ cheese_camera_device_get_caps_for_format (CheeseCameraDevice *device,
                                                           full_format));
   }
 
-  subset_caps = gst_caps_intersect (desired_caps, device->priv->caps);
+    priv = cheese_camera_device_get_instance_private (device);
+    subset_caps = gst_caps_intersect (desired_caps, priv->caps);
   subset_caps = gst_caps_simplify (subset_caps);
   gst_caps_unref (desired_caps);
 
